;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dune" "20250903.1130"
  "Integration with the dune build system."
  ()
  :url "https://github.com/ocaml/dune"
  :commit "1e54fd3f450aae7fb41ffb6b7c8b7a5aed754777"
  :revdesc "1e54fd3f450a")
